FilePreviewMenuAction class

预览页菜单项配置。

通过 FilePreviewConfig.menuActionsBuilder 注入, 点击后由 FilePreviewConfig.onMenuActionTap 回调分发给外部处理。

Constructors

FilePreviewMenuAction({required String id, required String label, Widget? icon})
创建一个菜单项。
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Widget?
菜单项图标(可选)。
final
id String
菜单项唯一标识,用于在回调中区分不同操作。
final
label String
菜单项显示文案。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited