FpOriginalButton class

查看原图按钮。

对齐主项目 ShowOriginalImageButtonWidget 的样式和逻辑:

  • 样式:毛玻璃背景 + 半透明深色圆角容器,居中显示
  • 未下载:显示「查看原图(2.5MB)」文字
  • 下载中:显示进度圆圈 + 百分比
  • 下载完成:按钮消失(不是变灰),图片渲染器自动切换到原图

通过 onOriginalReady 回调通知渲染器原图已就绪(本地文件路径)。

Inheritance

Constructors

FpOriginalButton({Key? key, required FilePreviewItem item, required BaseCacheManager cacheManager, void onOriginalReady(File file)?})
const

Properties

cacheManager → BaseCacheManager
final
hashCode int
The hash code for this object.
no setterinherited
item FilePreviewItem
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onOriginalReady → void Function(File file)?
原图下载完成后的回调,传入本地文件
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FpOriginalButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited